# Install and run ReacNetGenerator on Google Colaboratory

In this series of tutorials, we will try to install and run ReacNetGenerator on [Google Colaboratory](https://colab.research.google.com/). You can click the badget on each tutorial to view and repeat it.
